summaryrefslogtreecommitdiffstats
path: root/src/gui/stringmapdialog.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:06:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:06:16 -0600
commit7717bcec2ad7d94e3f38a2e831bafa60a525f7d2 (patch)
tree77ffa8fe14318bb3a285cae65dbe622bcbbcb3f9 /src/gui/stringmapdialog.h
parentb5cff83092d97189b5a55e1a996995207bc3016c (diff)
downloadtellico-7717bcec2ad7d94e3f38a2e831bafa60a525f7d2.tar.gz
tellico-7717bcec2ad7d94e3f38a2e831bafa60a525f7d2.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'src/gui/stringmapdialog.h')
-rw-r--r--src/gui/stringmapdialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gui/stringmapdialog.h b/src/gui/stringmapdialog.h
index 974bcf4..ac9b10a 100644
--- a/src/gui/stringmapdialog.h
+++ b/src/gui/stringmapdialog.h
@@ -15,7 +15,7 @@
#define STRINGMAPDIALOG_H
class KLineEdit;
-class KListView;
+class TDEListView;
class TQListViewItem;
#include <kdialogbase.h>
@@ -28,7 +28,7 @@ namespace Tellico {
/**
* @short A simple dialog for editing a map between two strings.
*
* A \ref KListView is used with the map keys in the first column and
* the map values in the second. Two edit boxes are below the list view.
* When an item is selected, the key-value is pair is placed in the edit
* boxes. Add and Delete buttons are used to add a new pair, or to remove
@@ -63,7 +63,7 @@ private slots:
void slotUpdate(TQListViewItem* item);
protected:
- KListView* m_listView;
+ TDEListView* m_listView;
KLineEdit* m_edit1;
KLineEdit* m_edit2;
};
@@ -28,7 +28,7 @@ namespace Tellico {
* @short A simple dialog for editing a map between two strings.
*
- * A \ref KListView is used with the map keys in the first column and
+ * A \ref TDEListView is used with the map keys in the first column and
* the map values in the second. Two edit boxes are below the list view.
* When an item is selected, the key-value is pair is placed in the edit